@@ -12,6 +12,9 @@
 #'   If `NULL`, column types will be imputed using all rows.
 #' @inheritParams tokenizer_delim
 #' @inheritParams read_delim
+#' @note `type_convert()` removes a 'spec' attribute,
+#' because it likely modifies the column data types.
+#' (see [spec()] for more information about column specifications).
 #' @export
 #' @examples
 #' df <- data.frame(
@@ -42,10 +45,7 @@ type_convert <- function(df, col_types = NULL, na = c("", "NA"), trim_ws = TRUE,
 
   col_types <- keep_character_col_types(df, col_types)
 
-  guesses <- lapply(char_cols, function(x) {
-    x[x %in% na] <- NA
-    guess_parser(x, locale)
-  })
+  guesses <- lapply(char_cols, guess_parser, locale = locale, na = na)
 
   specs <- col_spec_standardise(
     col_types = col_types,
@@ -53,7 +53,7 @@ type_convert <- function(df, col_types = NULL, na = c("", "NA"), trim_ws = TRUE,
     guessed_types =  guesses
   )
 
-  if (is.null(col_types)) {
+  if (is.null(col_types) && !is_testing()) {
     show_cols_spec(specs)
   }
 
@@ -62,6 +62,8 @@ type_convert <- function(df, col_types = NULL, na = c("", "NA"), trim_ws = TRUE,
       locale_ = locale, na = na, trim_ws = trim_ws)
   })
 
+  attr(df, "spec") <- NULL
+
   df
 }
 
